#include "lib_decors.h"

s_decor *create_decor(char *image_path,
					  int x_world,
					  int y_world,
					  int r_back,
					  int g_back,
					  int b_back)
{
	SDL_Surface *surface_tmp = NULL;
	s_decor *decor = NULL;

	if (image_path == NULL)
		return (NULL);
	surface_tmp = SDL_LoadBMP(image_path);
	if (surface_tmp == NULL)
		return (NULL);
	SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
	decor = malloc(sizeof (s_decor));
	decor->image = surface_tmp;
	decor->x_world = x_world;
	decor->y_world = y_world;
	decor->positionDst.x = x_world; //ATTENTION si negatif
	decor->positionDst.y = y_world; //ATTENTION si negatif
	decor->positionSrc.x = 0;
	decor->positionSrc.y = 0;
	decor->positionSrc.w = decor->image->w;
	decor->positionSrc.h = decor->image->h;
	decor->is_displayed = 1;

	return (decor);
}

SDL_Surface *free_structure_decor(s_decor *decor)
{
	SDL_Surface *image = decor->image;

	free(decor);
	return (image);
}

void free_everything_decor(s_decor *decor)
{
	SDL_FreeSurface(decor->image);
	free(decor);
}

void blit_decor(s_decor *decor, SDL_Surface *screen)
{
	if (decor->is_displayed == 0)
		SDL_BlitSurface(decor->image, &(decor->positionSrc), screen, &(decor->positionDst));
}

s_decor **make_decor_array(int nb_decor, ...)
{
	va_list arglist;
	s_decor **my_array = NULL;
	s_decor *tmp = NULL;
	int i = 0;

	va_start(arglist, nb_decor);
	my_array = malloc((nb_decor + 1) * sizeof (s_decor*));
	my_array[nb_decor] = NULL;
	while (i != nb_decor)
	{
		tmp = va_arg(arglist, s_decor*);
		if (tmp == NULL)
		{
			va_end(arglist);
			free(my_array);
			return (NULL);
		}
		my_array[i] = tmp;
		i++;
	}
	va_end(arglist);
	return (my_array);
}

void free_everything_decor_array(s_decor **my_array)
{
	int i = 0;

	while (my_array[i] != NULL)
	{
		free_everything_decor(my_array[i]);
		i++;
	}
	free(my_array);
}


/*
** SIMPLE BLINKING PART
*/

s_sblink_decor *create_sblink_decor(simple_blinking_surface *image,
									int x_world,
									int y_world)
{
	s_sblink_decor *decor = NULL;

	if (image == NULL)
		return (NULL);

	decor = malloc(sizeof (s_sblink_decor));
	decor->image = image;
	decor->x_world = x_world;
	decor->y_world = y_world;
	decor->positionDst.x = x_world; //ATTENTION si negatif
	decor->positionDst.y = y_world; //ATTENTION si negatif
	decor->positionSrc.x = 0;
	decor->positionSrc.y = 0;
	decor->positionSrc.w = decor->image->w;
	decor->positionSrc.h = decor->image->h;
	decor->is_displayed = 1;

	return (decor);
}


simple_blinking_surface *free_structure_sblink_decor(s_sblink_decor *decor)
{
	simple_blinking_surface *tmp = decor->image;

	free(decor);
	return (tmp);
}

void free_everything_sblink_decor(s_sblink_decor *decor)
{
	free_simple_surface(decor->image);
	free(decor);
}

void blit_sblink_decor(s_sblink_decor *decor, SDL_Surface *screen)
{
	if (decor->is_displayed == 0)
		blit_simple_blinking_surface_from_to(decor->image, screen, decor->positionSrc, decor->positionDst);
}

void update_sblink_decor(s_sblink_decor *decor)
{
	update_simple_blinking(decor->image);
}

s_sblink_decor **make_sblink_decor_array(int nb_decor, ...)
{
	va_list arglist;
	s_sblink_decor **my_array = NULL;
	s_sblink_decor *tmp = NULL;
	int i = 0;

	va_start(arglist, nb_decor);
	my_array = malloc((nb_decor + 1) * sizeof (s_sblink_decor*));
	my_array[nb_decor] = NULL;
	while (i != nb_decor)
	{
		tmp = va_arg(arglist, s_sblink_decor*);
		if (tmp == NULL)
		{
			va_end(arglist);
			free(my_array);
			return (NULL);
		}
		my_array[i] = tmp;
		i++;
	}
	va_end(arglist);
	return (my_array);
}

void free_everything_sblink_decor_array(s_sblink_decor **my_array)
{
	int i = 0;

	while (my_array[i] != NULL)
	{
		free_everything_sblink_decor(my_array[i]);
		i++;
	}
	free(my_array);
}
