#ifndef LIB_DECORS_H_

# define LIB_DECORS_H_

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

# include "lib_simple_blinking.h"
# include "lib_sprite.h"
# include "gestion_monde.h"

typedef	struct s_decor
{
	SDL_Surface *image;			//The SDL_Surface
	SDL_Rect positionSrc;		//Positon on the sprite to read (Modify it YOURSELF)
	SDL_Rect positionDst;		//Position on the screen where to blit
	int x_world;				//X position in the world
	int y_world;				//Y position in the world
	int is_displayed;			//0 == is blitted, else, not blitted
} s_decor;

/*
** Create a decor, you have to give it the s_sprites array and it's lenght,
** don't forget the x and y to the SDL_Rect where to blit.
** If image == NULL, it does NOT create the struct, and return NULL.
*/
s_decor *create_decor(char *image_path,
					  int x_world,
					  int y_world,
					  int r_back,
					  int g_back,
					  int b_back);

/*
** Free ONLY the structure, NOT the SDL_Surface* !
*/
SDL_Surface *free_structure_decor(s_decor *decor);

/*
** Free EVERYTHING in the s_decor
*/
void free_everything_decor(s_decor *decor);

/*
** Blit, from PositionSrc, the current sprite at PositionDst on the screen,
*/
void blit_decor(s_decor *decor, SDL_Surface *screen);

/*
** Create a s_decor** array by giving the number of decors
** and one deco per argument
*/
s_decor **make_decor_array(int nb_perso, ...);

/*
** Free every decor in the array, and free the array
*/
void free_everything_decor_array(s_decor **my_array);


/*
** SIMPLE BLINKING PART
*/

typedef	struct s_sblink_decor
{
	struct simple_blinking_surface *image;	//The SDL_Surface
	SDL_Rect positionSrc;					//Positon on the sprite to read (Modify it YOURSELF)
	SDL_Rect positionDst;					//Position on the screen where to blit
	int x_world;							//X position in the world
	int y_world;							//Y position in the world
	int is_displayed;						//0 == is blitted, else, not blitted
} s_sblink_decor;


/*
** Create a decor, you have to give it the s_sprites array and it's lenght,
** don't forget the x and y to the SDL_Rect where to blit.
** If image == NULL, it does NOT create the struct, and return NULL.
*/
s_sblink_decor *create_sblink_decor(simple_blinking_surface *image,
									int x_world,
									int y_world);

/*
** Free ONLY the structure, NOT the simple_blinking_surface* !
*/
simple_blinking_surface *free_structure_sblink_decor(s_sblink_decor *decor);

/*
** Free EVERYTHING in the s_sblink_decor
*/
void free_everything_sblink_decor(s_sblink_decor *decor);

/*
** Blit, from PositionSrc, the current sprite at PositionDst on the screen,
*/
void blit_sblink_decor(s_sblink_decor *decor, SDL_Surface *screen);

/*
** Update the blinking surface
*/
void update_sblink_decor(s_sblink_decor *decor);

/*
** Create a s_sblink_decor** array by giving the number of decors
** and one deco per argument
*/
s_sblink_decor **make_sblink_decor_array(int nb_decor, ...);

/*
** Free every decor in the array, and free the array
*/
void free_everything_sblink_decor_array(s_sblink_decor **my_array);

#endif /* !LIB_DECORS_H_ */
