#include "lib_personnage.h"

s_personnage *create_personnage(s_sprite **sprites,
								int max_sprites,
								int x_world,
								int y_world)
{
	s_personnage *personnage = NULL;

	if (sprites == NULL)
		return (NULL);

	personnage = malloc(sizeof (s_personnage));
	personnage->sprites = sprites;
	personnage->max_sprites = max_sprites;
	personnage->x_world = x_world;
	personnage->y_world = y_world;
	personnage->positionDst.x = x_world;  //ATTENTION si negatif
	personnage->positionDst.y = y_world;  //ATTENTION si negatif
	personnage->positionSrc.x = 0;
	personnage->positionSrc.y = 0;
	personnage->positionSrc.w = sprites[0]->images[0]->w;
	personnage->positionSrc.h = sprites[0]->images[0]->h;
	personnage->current_sprite = 0;
	personnage->is_displayed = 1;

	return (personnage);
}

s_personnage *tool_create_personnage_from_char(int x_world,
											   int y_world,
											   int r_back,
											   int g_back,
											   int b_back,
											   int max_sprites,
											   ...)
{
	va_list arglist;
	s_personnage *personnage = NULL;
	s_sprite **sprite_array = NULL;
	s_sprite *sprite = NULL;
	int i = 0;

	va_start(arglist, max_sprites);
	sprite_array = malloc((max_sprites + 1) * sizeof (s_sprite*));
	while (i != max_sprites)
	{
		sprite = create_sprite(va_arg(arglist, char**), 0, x_world, y_world, r_back, g_back, b_back);
		if (sprite == NULL)
		{
			va_end(arglist);
			free(sprite_array);
			return (NULL);
		}
		sprite_array[i] = sprite;
		i++;
	}
	sprite_array[i] = NULL;

	personnage = malloc(sizeof (s_personnage));

	personnage->sprites = sprite_array;
	personnage->max_sprites = max_sprites;
	personnage->x_world = x_world;
	personnage->y_world = y_world;
	personnage->positionDst.x = x_world;  //ATTENTION si negatif
	personnage->positionDst.y = y_world;  //ATTENTION si negatif
	personnage->positionSrc.x = 0;
	personnage->positionSrc.y = 0;
	personnage->positionSrc.w = sprite_array[0]->images[0]->w;
	personnage->positionSrc.h = sprite_array[0]->images[0]->h;
	personnage->is_displayed = 1;
	personnage->current_sprite = 0;
	
	va_end(arglist);
	return (personnage);
}

s_sprite **free_structure_personnage(s_personnage *personnage)
{
	s_sprite **sprites = personnage->sprites;

	free(personnage);
	return (sprites);
}

void free_everything_personnage(s_personnage *personnage)
{
	s_sprite **sprites = personnage->sprites;
	int max = personnage->max_sprites;
	int i = 0;

	while (i != max)
	{
		free_sprite(sprites[i]);
		i++;
	}
	free(sprites);
	free(personnage);
}

void blit_personnage(s_personnage *personnage, SDL_Surface *screen)
{
	if (personnage->is_displayed == 0)
		blit_sprite_from_to(personnage->sprites[personnage->current_sprite], screen, personnage->positionSrc, personnage->positionDst);
}

void update_personnage(s_personnage *personnage)
{
	update_sprite(personnage->sprites[personnage->current_sprite]);
}

int change_sprite_personnage(s_personnage *personnage, int new_sprite)
{
	if (new_sprite < personnage->max_sprites)
	{
		personnage->current_sprite = new_sprite;
		personnage->sprites[new_sprite]->frame_counter = 0;
		personnage->positionSrc.w = personnage->sprites[new_sprite]->width;
		personnage->positionSrc.h = personnage->sprites[new_sprite]->height;
	}
	else
		return (-1);
	return(0);
}

s_personnage **make_personnage_array(int nb_perso, ...)
{
	va_list arglist;
	s_personnage **my_array = NULL;
	s_personnage *tmp = NULL;
	int i = 0;

	va_start(arglist, nb_perso);
	my_array = malloc((nb_perso + 1) * sizeof (s_personnage*));
	my_array[nb_perso] = NULL;
	while (i != nb_perso)
	{
		tmp = va_arg(arglist, s_personnage*);
		if (tmp == NULL)
		{
			va_end(arglist);
			free(my_array);
			return (NULL);
		}
		my_array[i] = tmp;
		i++;
	}
	va_end(arglist);
	return (my_array);
}

void free_everything_personnage_array(s_personnage **my_array)
{
	int i = 0;

	while (my_array[i] != NULL)
	{
		free_everything_personnage(my_array[i]);
		i++;
	}
	free(my_array);
}
