#ifndef LIB_PERSONNAGE_H_

# define LIB_PERSONNAGE_H_

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

# include "lib_sprite.h"
# include "gestion_monde.h"

typedef	struct s_personnage
{
	struct s_sprite **sprites;	//Array of sprites
	SDL_Rect positionSrc;		//Positon on the sprite to read (Modify it YOURSELF)
	SDL_Rect positionDst;		//Position on the screen where to blit
	int max_sprites;			//Lenght of the sprites array
	int current_sprite;			//Current sprite that is used
	int x_world;				//X position in the world
	int y_world;				//Y position in the world
	int is_displayed;			//0 == is blitted, else, not blitted
} s_personnage;

/*
** Create a personnage, you have to give it the s_sprites array and it's lenght,
** don't forget the x and y to the SDL_Rect where to blit.
** If sprites == NULL, it does NOT create the struct, and return NULL.
** By default, personnage are NOT displayed
*/
s_personnage *create_personnage(struct s_sprite **sprites,
								int max_sprites,
								int x_world,
								int y_world);

/*
** Create a personnage, you have to give it the char** array and it's lenght,
** don't forget the x and y to the SDL_Rect where to blit, and the
** background color for transparency.
** If sprites == NULL, it does NOT create the struct, and return NULL.
*/
s_personnage *tool_create_personnage_from_char(int x_world,
											   int y_world,
											   int r_back,
											   int g_back,
											   int b_back,
											   int max_sprites,
											   ...);

/*
** Free ONLY the structure, NOT the s_sprites* !
** Be sure that the s_sprite* finishes by a NULL pointer, or you know it lenght.
*/
s_sprite **free_structure_personnage(s_personnage *personnage);

/*
** Free EVERYTHING in the s_personnage (except the world)
*/
void free_everything_personnage(s_personnage *personnage);

/*
** Blit, from PositionSrc, the current sprite at PositionDst on the screen,
*/
void blit_personnage(s_personnage *personnage, SDL_Surface *screen);

/*
** Update the current sprite state
** You can add your code inside this one to make some transition between
** specifics sprites you choose
*/
void update_personnage(s_personnage *personnage);

/*
** Change the sprite that is printed, by updating the chosen sprite state
** You can add your code inside this one to make some transition between
** specifics sprites you choose
*/
int change_sprite_personnage(s_personnage *personnage, int new_sprite);

/*
** Create a s_personnage** array by giving the number of personnages
** and one personnage per argument
*/
s_personnage **make_personnage_array(int nb_perso, ...);

/*
** Free every personnage in the array, and free the array
*/
void free_everything_personnage_array(s_personnage **my_array);

#endif /* !LIB_PERSONNAGE_H_ */
