#include "lib_simple_blinking.h"

simple_blinking_surface *create_simple_surface(char *img_back,
											   char *img_front,
											   char is_blinking,
											   int dynamic_blink_gap,
											   int x,
											   int y,
											   int r_back,
											   int g_back,
											   int b_back)
{
	simple_blinking_surface *surface = NULL;
	SDL_Surface *surface_tmp = NULL;
	int	tab_len = 0;
	int i = 0;

	surface = malloc(sizeof (simple_blinking_surface));
	surface_tmp = SDL_LoadBMP(img_back);
	if (surface_tmp == NULL)
	{
		free(surface);
		return (NULL);
	}
	SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
	surface->img_back = surface_tmp;
	
	surface_tmp = SDL_LoadBMP(img_front);
	if (surface_tmp == NULL)
	{
		SDL_FreeSurface(surface->img_back);
		free(surface);
		return (NULL);
	}
	SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
	surface->img_front = surface_tmp;
	
	surface->dynamic_blink_gap = dynamic_blink_gap;
	surface->position.x = x;
	surface->position.y = y;
	surface->blink_lvl = 0;
	surface->is_disapearing = 0;
	if (is_blinking == 0)
	{
		//Not blinking
		surface->is_blinking = 0;
		surface->tab_len = 0;
		surface->tab_front = NULL;
	}
	else
	{
		//Blinking
		surface->is_blinking = 1;
		if (dynamic_blink_gap == 0)
			tab_len = 255 / SIMPLE_BLINK_GAP;
		else
			tab_len = 255 / dynamic_blink_gap;
		surface->tab_len = tab_len;
		surface->tab_front = malloc((tab_len + 1) * sizeof (SDL_Surface*));
		while (i != (tab_len + 1))
		{
			surface_tmp = SDL_LoadBMP(img_front);
			SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
			if (dynamic_blink_gap == 0)
			{
				if ((i * SIMPLE_BLINK_GAP) > 255)
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
				else
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * SIMPLE_BLINK_GAP));
			}
			else
			{
				if ((i * dynamic_blink_gap) > 255)
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
				else
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * dynamic_blink_gap));
			}
			surface->tab_front[i] = surface_tmp;
			i++;
		}
	}
	surface->w = surface->img_back->w;
	surface->h = surface->img_back->h;

	return (surface);
}

void free_simple_surface(simple_blinking_surface *surface)
{
	int i = 0;

	SDL_FreeSurface(surface->img_back);
	SDL_FreeSurface(surface->img_front);
	if (surface->is_blinking != 0)
	{
		//Blinking
		while (i != (surface->tab_len + 1))
		{
			SDL_FreeSurface(surface->tab_front[i]);
			i++;
		}
		free(surface->tab_front);
	}
	free(surface);
}

void blit_simple_blinking_surface(simple_blinking_surface *surface, SDL_Surface *screen)
{
	SDL_BlitSurface(surface->img_back, NULL, screen, &(surface->position));
	SDL_BlitSurface(surface->tab_front[surface->blink_lvl], NULL, screen, &(surface->position));
}

void blit_simple_blinking_surface_from(simple_blinking_surface *surface,
									   SDL_Surface *screen,
									   SDL_Rect PositionSrc)
{
	SDL_BlitSurface(surface->img_back, &(PositionSrc), screen, &(surface->position));
	SDL_BlitSurface(surface->tab_front[surface->blink_lvl], &(PositionSrc), screen, &(surface->position));
}

void blit_simple_blinking_surface_from_to(simple_blinking_surface *surface,
										  SDL_Surface *screen,
										  SDL_Rect PositionSrc,
										  SDL_Rect PositionDst)
{
	SDL_BlitSurface(surface->img_back, &(PositionSrc), screen, &(PositionDst));
	SDL_BlitSurface(surface->tab_front[surface->blink_lvl], &(PositionSrc), screen, &(PositionDst));
}

void update_simple_blinking(simple_blinking_surface *surface)
{
	if (surface->is_blinking != 0)
	{
		if (surface->is_disapearing == 0)
		{
			if (surface->blink_lvl == surface->tab_len)
				surface->is_disapearing = 1;
			else
				surface->blink_lvl += 1;
		}
		else
		{
			if (surface->blink_lvl == 0)
				surface->is_disapearing = 0;
			else
				surface->blink_lvl -= 1;
		}
	}
}
