#ifndef LIB_SPRITE_H_

# define LIB_SPRITE_H_

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

typedef	struct s_sprite
{
	SDL_Surface **images;		//Front pictures
	SDL_Rect position;			//Position of the sprite on the screen for blitting
	int frame_counter;			//The frame counter (don't modify it yourself)
	int max_frame;				//The lenght of the images/Total frame number (don't modify it yourself)
	int is_frozen;				//0 the sprite will change, something else keep the image
	int width;					//Width of the first picture (all pics should have the same)
	int height;					//Height of the first picture (all pics should have the same)
} s_sprite;

/*
** Create a complex_blinking_surface* that contain everything
** img_tab is the array of the pathes to the front pictures
** is_frozen put 0 for an active sprite, or anything other to inactivate it
** x is the position.x of the blinking surface
** y is the position.y of the blinking surface
** r_back is the red level of the transparent background
** g_back is the green level of the transparent background
** b_back is the blue level of the transparent background
*/
s_sprite *create_sprite(char **img_tab,
						int is_frozen,
						int x,
						int y,
						int r_back,
						int g_back,
						int b_back);

/*
** Free the sprite, and all the component inside
*/
void free_sprite(s_sprite *my_sprite);

/*
** Blit the sprite to a SDL_Surface (generally a screen)
*/
void blit_sprite(s_sprite *my_sprite, SDL_Surface *screen);

/*
** Blit a part of the sprite to a SDL_Surface (generally a screen)
*/
void blit_sprite_from(s_sprite *my_sprite, SDL_Surface *screen, SDL_Rect PositionSrc);

/*
** Blit a part of the sprite somewhere on a SDL_Surface (generally a screen)
*/
void blit_sprite_from_to(s_sprite *my_sprite, SDL_Surface *screen, SDL_Rect PositionSrc, SDL_Rect PositionDst);

/*
** Each turn of the game, you have to update the complex_blinking_surface
** Call this procedure tu update the blinking level.
** If you put is_frozen to 0, the image is NOT updated !
*/
void update_sprite(s_sprite *my_sprite);

/*
** Create an array with the sprites you give to it.
** It returns NULL if one of the sprites is NULL, or
** if you give it 0 sprite.
*/
s_sprite **make_sprite_array(int nb_sprite, ...);

/*
** Free only the array, not the cells
*/
void free_structure_sprite_array(s_sprite **sprite_array);

/*
** Free everything in the array of sprites, and the array itself
*/
void free_everything_sprite_array(s_sprite **sprite_array);

#endif /* !LIB_SPRITE_H_ */
