#ifndef LIB_COMPLEX_BLINKING_H_

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

/*
** The gap between the blinking lvl
** 20 is a low gap, and 50 is not bad
** It is hardcoded, but you can add this value in the structure if you want
** and modify the lib_blinking.c that is associated to make different
** blinking's gap per sprite !
** This one is the Static blink_gap, use it if you will blink at the same
** level everywhere
*/
# define COMPLEX_BLINK_GAP 50

typedef	struct complex_blinking_surface
{
	SDL_Surface *img_back;		//Background picture
	SDL_Surface **img_front;	//Front pictures
	SDL_Surface ***tab_front;	//Array of precalculate blinking surface (don't modify it yourself) == *SDLSurface[][]
	SDL_Rect position;			//Position of the sprite
	char is_blinking;			//0 not blinking, 1 is blinking
	int	blink_lvl;				//Level of blinking (0 < n < 255) (don't modify it yourself)
	int frame_counter;			//The frame counter (don't modify it yourself)
	int max_frame;				//The lenght of the img_front array/Total frame number (don't modify it yourself)
	int max_subframe;			//The lenght of the each array in tab_front[frame_counter] (don't modify it yourself)
	int dynamic_blink_gap;		//Dynamic blink gap (0 == static gap, else == dynamic gap)
} complex_blinking_surface;

/*
** Create a complex_blinking_surface* that contain everything
** img_back is the path to the back picture
** img_front is the tab of the pathes to the front pictures
** is_blinking put 0 for not blinking, or anything other to blink
** dynamic_blink_gap put 0 for static blinking gap, something else for dynamic
** x is the position.x of the blinking surface
** y is the position.y of the blinking surface
** r_back is the red level of the transparent background
** g_back is the green level of the transparent background
** b_back is the blue level of the transparent background
*/
complex_blinking_surface *create_complex_surface(char *img_back,
												 char **img_front,
												 char is_blinking,
												 int dynamic_blink_gap,
												 int x,
												 int y,
												 int r_back,
												 int g_back,
												 int b_back);

/*
** Free the complex_blinking_surface, and all the component inside
*/
void free_complex_surface(complex_blinking_surface *surface);

/*
** Blit the complex_blinking_surface to a SDL_Surface (generally a screen)
*/
void blit_complex_blinking_surface(complex_blinking_surface *surface, SDL_Surface *screen);

/*
** Each turn of the game, you have to update the complex_blinking_surface
** Call this procedure tu update the blinking level.
** If you put is_blinking to 0, the level is NOT updated !
*/
void update_complex_blinking(complex_blinking_surface *surface);

#endif /* !LIB_COMPLEX_BLINKING_H_ */
