#include "lib_complex_blinking.h"

static int get_tab_len(char **img_front)
{
	int len = 0;

	if (img_front == NULL)
		return (0);
	if (img_front[0] == NULL)
		return (0);
	while (img_front[len] != NULL)
		len++;
//	return (len);
	return (len + 1);
}

static void urgent_free(SDL_Surface **tab_surface,
						int i)
{
	while (i != 0)
	{
		i--;
		SDL_FreeSurface(tab_surface[i]);
	}
	free(tab_surface);
}

static int get_max_subframe(int dynamic_blink_gap)
{
	int nb_frame = 0;

	if (dynamic_blink_gap == 0)
	{
		nb_frame = (255 / COMPLEX_BLINK_GAP);
		if (nb_frame < 0)
			return (0);
		if ((255 % COMPLEX_BLINK_GAP) != 0)
			nb_frame++;
	}
	else
	{
		nb_frame = (255 / dynamic_blink_gap);
		if (nb_frame < 0)
			return (0);
		if ((255 % dynamic_blink_gap) != 0)
			nb_frame++;
	}

	return (nb_frame);
}

static SDL_Surface **put_sdl_surface(char *img_back,
									 char **img_front,
									 int len,
									 int r_back,
									 int g_back,
									 int b_back)
{
	SDL_Surface **tab_surface = NULL;
	SDL_Surface *surface_tmp = NULL;
	int i = 0;
	int j = 0;

	tab_surface = malloc(len * sizeof (SDL_Surface*));
	//while (i != len)
	while (i != (len - 1))
	{
		surface_tmp = SDL_LoadBMP(img_front[i]);
		if (surface_tmp == NULL)
		{
			urgent_free(tab_surface, i);
			return (NULL);
		}
		SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
		tab_surface[i] = surface_tmp;
		i++;
	}
	//The background one...
	surface_tmp = SDL_LoadBMP(img_back);
	if (surface_tmp == NULL)
	{
		urgent_free(tab_surface, i);
		return (NULL);
	}
	SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
	tab_surface[i] = surface_tmp;

	return (tab_surface);
}

/*
** Adding the last frame that is the background blinking
*/
static void last_frame_front_tab(complex_blinking_surface *surface,
								 char *img_back,
								 int max_frame,
								 int dynamic_blink_gap,
								 int r_back,
								 int g_back,
								 int b_back,
								 int frame)
{
	SDL_Surface *surface_tmp = NULL;
	int nb_frame = surface->max_subframe;
	int i = 0;

	surface->tab_front[frame] = malloc((nb_frame + 1) * sizeof (SDL_Surface*));
	while (i != nb_frame)
	{
		surface_tmp = SDL_LoadBMP(img_back);
		SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
		if (dynamic_blink_gap == 0)
		{
			if ((i * COMPLEX_BLINK_GAP) >= 255)
				SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
			else
				SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * COMPLEX_BLINK_GAP));
		}
		else
		{
			if ((i * dynamic_blink_gap) >= 255)
				SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
			else
				SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * dynamic_blink_gap));
		}
		surface->tab_front[frame][i] = surface_tmp;
		i++;
	}
}

/*
** For each front picture, we generate an array with alpha pictures
*/
static void create_front_tab(complex_blinking_surface *surface,
							 char *img_back,
							 char **img_front,
							 int max_frame,
							 int dynamic_blink_gap,
							 int r_back,
							 int g_back,
							 int b_back)
{
	SDL_Surface **tab_surface = NULL;
	SDL_Surface *surface_tmp = NULL;
	int nb_frame = 0;
	int condition = 0;
	int frame = 0;
	int i = 0;

	surface->tab_front = malloc((max_frame + 1) * sizeof (SDL_Surface**));
	nb_frame = get_max_subframe(dynamic_blink_gap);
	surface->max_subframe = nb_frame;

	//while (frame != max_frame)
	while (frame != (max_frame - 1))
	{
		i = 0;
		condition = 0;
		surface->tab_front[frame] = malloc((nb_frame + 1) * sizeof (SDL_Surface*));
		while (i != nb_frame)
		{
			surface_tmp = SDL_LoadBMP(img_front[frame]);
			SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
			if (dynamic_blink_gap == 0)
			{
				if ((i * COMPLEX_BLINK_GAP) >= 255)
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
				else
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * COMPLEX_BLINK_GAP));
			}
			else
			{
				if ((i * dynamic_blink_gap) >= 255)
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, 255);
				else
					SDL_SetAlpha(surface_tmp, SDL_SRCALPHA, (i * dynamic_blink_gap));
			}
			surface->tab_front[frame][i] = surface_tmp;
			i++;
		}
		frame++;
	}
	last_frame_front_tab(surface, img_back, max_frame, dynamic_blink_gap, r_back, g_back, b_back, frame);
}

complex_blinking_surface *create_complex_surface(char *img_back,
												 char **img_front,
												 char is_blinking,
												 int dynamic_blink_gap,
												 int x,
												 int y,
												 int r_back,
												 int g_back,
												 int b_back)
{
	complex_blinking_surface *surface = NULL;
	SDL_Surface **tab_surface = NULL;
	SDL_Surface *surface_tmp = NULL;
	int max_frame = 0;
	int	tab_len = 0;

	surface = malloc(sizeof (complex_blinking_surface));
	
	surface_tmp = SDL_LoadBMP(img_back);
	if (surface_tmp == NULL)
	{
		free(surface);
		return (NULL);
	}
	SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
	surface->img_back = surface_tmp;

	max_frame = get_tab_len(img_front);
	tab_surface = put_sdl_surface(img_back, img_front, max_frame, r_back, g_back, b_back);
	if (tab_surface == NULL)
	{
		SDL_FreeSurface(surface->img_back);
		free(surface);
		return (NULL);
	}
	surface->max_frame = max_frame;
	surface->img_front = tab_surface;

	surface->dynamic_blink_gap = dynamic_blink_gap;
	surface->position.x = x;
	surface->position.y = y;
	surface->blink_lvl = 0;
	surface->frame_counter = 0;
	if (is_blinking == 0)
	{
		//Not blinking
		surface->is_blinking = 0;
		surface->max_subframe = 0;
		surface->tab_front = NULL;
	}
	else
	{
		//Blinking
		surface->is_blinking = 1;
		create_front_tab(surface, img_back, img_front, max_frame, dynamic_blink_gap, r_back, g_back, b_back);
	}

	return (surface);
}

void free_complex_surface(complex_blinking_surface *surface)
{
	int i = 0;
	int j = 0;

	SDL_FreeSurface(surface->img_back);
	while (i != surface->max_frame)
	{
		SDL_FreeSurface(surface->img_front[i]);
		i++;
	}
	free(surface->img_front);

	if (surface->is_blinking != 0)
	{
		//Blinking
		while (j != surface->max_frame)
		{
			i = 0;
			while (i != surface->max_subframe)
			{	
				SDL_FreeSurface(surface->tab_front[j][i]);
				i++;
			}
			free(surface->tab_front[j]);
			j++;
		}
		free(surface->tab_front);
	}
	free(surface);
}

void blit_complex_blinking_surface(complex_blinking_surface *surface, SDL_Surface *screen)
{
	int frame_counter = surface->frame_counter;

	SDL_BlitSurface(surface->img_back, NULL, screen, &(surface->position));
	if (frame_counter > 0)
		SDL_BlitSurface(surface->img_front[frame_counter - 1], NULL, screen, &(surface->position));
	SDL_BlitSurface(surface->tab_front[frame_counter][surface->blink_lvl], NULL, screen, &(surface->position));
}

void update_complex_blinking(complex_blinking_surface *surface)
{
	if (surface->is_blinking != 0)
	{
		if (surface->frame_counter == (surface->max_frame - 1))
		{
			if (surface->blink_lvl == (surface->max_subframe - 1))
			{
				surface->frame_counter = 0;
				surface->blink_lvl = 0;
			}
			else
				surface->blink_lvl += 1;
		}
		else
		{
			if (surface->blink_lvl == (surface->max_subframe - 1))
			{
				surface->frame_counter += 1;
				surface->blink_lvl = 0;
			}
			else
				surface->blink_lvl += 1;
		}
	}
}
