#ifndef LIB_SIMPLE_BLINKING_H_

# ifdef _DEBUG
// LEAK DETECTION
#  define _CRTDBG_MAP_ALLOC
#  include <stdlib.h>
#  include <crtdbg.h>
// END OF LEAK DETECTION
# endif /* !_DEBUG */

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

/*
** The gap between the blinking lvl
** 20 is a low gap, and 50 is not bad
** It is hardcoded, but you can add this value in the structure if you want
** and modify the lib_blinking.c that is associated to make different
** blinking's gap per sprite !
** This one is the Static blink_gap, use it if you will blink at the same
** level everywhere
*/
# define SIMPLE_BLINK_GAP 50

typedef	struct simple_blinking_surface
{
	SDL_Surface *img_back;		//Background picture
	SDL_Surface *img_front;		//Front picture
	SDL_Surface **tab_front;	//Array of precalculate blinking surface (don't modify it yourself)
	SDL_Rect position;			//Position of the sprite
	char is_blinking;			//0 not blinking, 1 is blinking
	int	blink_lvl;				//Level of blinking (don't modify it yourself)
	int is_disapearing;			//To know if the sprite is going transparent or not (don't modify it yourself)
	int tab_len;				//The lenght of the array (don't modify it yourself)
	int dynamic_blink_gap;		//Dynamic blink gap (0 == static gap, else == dynamic gap)
} simple_blinking_surface;

/*
** Create a simple_blinking_surface* that contain everything
** img_back is the path to the back picture
** img_front is the path to the front picture (the one blinking)
** is_blinking put 0 for not blinking, or anything other to blink
** dynamic_blink_gap put 0 for static blinking gap, something else for dynamic
** x is the position.x of the blinking surface
** y is the position.y of the blinking surface
** r_back is the red level of the transparent background
** g_back is the green level of the transparent background
** b_back is the blue level of the transparent background
*/
simple_blinking_surface *create_simple_surface(char *img_back,
											   char *img_front,
											   char is_blinking,
											   int dynamic_blink_gap,
											   int x,
											   int y,
											   int r_back,
											   int g_back,
											   int b_back);

/*
** Free the simple_blinking_surface, and all the component inside
*/
void free_simple_surface(simple_blinking_surface *surface);

/*
** Blit the simple_blinking_surface to a SDL_Surface (generally a screen)
*/
void blit_simple_blinking_surface(simple_blinking_surface *surface, SDL_Surface *screen);

/*
** Each turn of the game, you have to update the simple_blinking_surface
** Call this procedure tu update the blinking level.
** If you put is_blinking to 0, the level is NOT updated !
*/
void update_simple_blinking(simple_blinking_surface *surface);

#endif /* !LIB_SIMPLE_BLINKING_H_ */
