#include "lib_sprite.h"

static int get_tab_len(char **img_tab)
{
	int len = 0;

	if (img_tab == NULL)
		return (0);
	if (img_tab[0] == NULL)
		return (0);
	while (img_tab[len] != NULL)
		len++;
	return (len);
}

static void urgent_free(SDL_Surface **tab_surface,
						int i)
{
	while (i != 0)
	{
		i--;
		SDL_FreeSurface(tab_surface[i]);
	}
	free(tab_surface);
}

sprite *create_sprite(char **img_tab,
					  int is_frozen,
					  int x,
					  int y,
					  int r_back,
					  int g_back,
					  int b_back)
{
	SDL_Surface **tab_surface = NULL;
	SDL_Surface *surface_tmp = NULL;
	sprite *my_sprite = NULL;
	int max_frame = 0;
	int i = 0;

	max_frame = get_tab_len(img_tab);
	tab_surface = malloc((max_frame + 1) * sizeof (SDL_Surface*));
	while (i != max_frame)
	{ 
		surface_tmp = SDL_LoadBMP(img_tab[i]);
		if (surface_tmp == NULL)
		{
			urgent_free(tab_surface, i);
			return (NULL);
		}
		SDL_SetColorKey(surface_tmp, SDL_SRCCOLORKEY, SDL_MapRGB(surface_tmp->format, r_back, g_back, b_back));
		tab_surface[i] = surface_tmp;
		i++;
	}

	my_sprite = malloc(sizeof (sprite));

	my_sprite->images = tab_surface;
	my_sprite->is_frozen = is_frozen;
	my_sprite->position.x = x;
	my_sprite->position.y = y;
	my_sprite->frame_counter = 0;
	my_sprite->max_frame = max_frame;
	
	return (my_sprite);
}


void free_sprite(sprite *my_sprite)
{
	int max_frame = my_sprite->max_frame;
	int i = 0;

	while (i != max_frame)
	{
		SDL_FreeSurface(my_sprite->images[i]);
		i++;
	}
	free(my_sprite->images);
	free(my_sprite);
}

void blit_sprite(sprite *my_sprite, SDL_Surface *screen)
{
	SDL_BlitSurface(my_sprite->images[my_sprite->frame_counter], NULL, screen, &(my_sprite->position));
}

void update_sprite(sprite *my_sprite)
{
	if (my_sprite->is_frozen == 0)
	{
		if (my_sprite->frame_counter == (my_sprite->max_frame - 1))
			my_sprite->frame_counter = 0;
		else
			my_sprite->frame_counter += 1;
	}
}
