#ifndef LIB_SPRITE_H_

# ifdef _DEBUG
// LEAK DETECTION
#  define _CRTDBG_MAP_ALLOC
#  include <stdlib.h>
#  include <crtdbg.h>
// END OF LEAK DETECTION
# endif /* !_DEBUG */

# include <stdlib.h>
# include <SDL/SDL.h>
# include <SDL/SDL_image.h>

typedef	struct sprite
{
	SDL_Surface **images;		//Front pictures
	SDL_Rect position;			//Position of the sprite
	int frame_counter;			//The frame counter (don't modify it yourself)
	int max_frame;				//The lenght of the images/Total frame number (don't modify it yourself)
	int is_frozen;				//0 the sprite will change, something else keep the image
} sprite;

/*
** Create a complex_blinking_surface* that contain everything
** img_tab is the array of the pathes to the front pictures
** is_frozen put 0 for an active sprite, or anything other to inactivate it
** x is the position.x of the blinking surface
** y is the position.y of the blinking surface
** r_back is the red level of the transparent background
** g_back is the green level of the transparent background
** b_back is the blue level of the transparent background
*/
sprite *create_sprite(char **img_tab,
					  int is_frozen,
					  int x,
					  int y,
					  int r_back,
					  int g_back,
					  int b_back);

/*
** Free the sprite, and all the component inside
*/
void free_sprite(sprite *my_sprite);

/*
** Blit the sprite to a SDL_Surface (generally a screen)
*/
void blit_sprite(sprite *my_sprite, SDL_Surface *screen);

/*
** Each turn of the game, you have to update the complex_blinking_surface
** Call this procedure tu update the blinking level.
** If you put is_frozen to 0, the image is NOT updated !
*/
void update_sprite(sprite *my_sprite);

#endif /* !LIB_SPRITE_H_ */
